==> haskell-unicode-transforms-0.3.2-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unicode-transforms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unicode-transforms
version: 0.3.2
id: unicode-transforms-0.3.2-DvGEYoRP1iD3W8nOEWI7Xe
key: unicode-transforms-0.3.2-DvGEYoRP1iD3W8nOEWI7Xe
license: BSD3
copyright: 2016-2017 Harendra Kumar,
           2014–2015 Antonio Nikishaev
maintainer: harendra.kumar@gmail.com
stability: Experimental
homepage: http://github.com/harendra-kumar/unicode-transforms
synopsis: Unicode normalization
description:
    Fast Unicode 9.0 normalization in Haskell (NFC, NFKC, NFD, NFKD).
category: Data,Text,Unicode
author: Harendra Kumar
exposed: True
exposed-modules:
    Data.ByteString.UTF8.Normalize Data.Text.Normalize
    Data.Unicode.Types
hidden-modules: Data.Unicode.Internal.NormalizeStream
                Data.Unicode.Properties.BitArray
                Data.Unicode.Properties.CombiningClass
                Data.Unicode.Properties.Compositions
                Data.Unicode.Properties.Decomposable
                Data.Unicode.Properties.DecomposableK
                Data.Unicode.Properties.Decompose
                Data.Unicode.Properties.DecomposeHangul
                Data.Unicode.Properties.Decompositions
                Data.Unicode.Properties.DecompositionsK
                Data.Unicode.Properties.DecompositionsK2
abi: 20121fafd85c2ed5472de5da13c4be54
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/unicode-transforms-0.3.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/unicode-transforms-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/unicode-transforms-0.3.2
hs-libraries: HSunicode-transforms-0.3.2-DvGEYoRP1iD3W8nOEWI7Xe
depends:
    base-4.9.1.0 bitarray-0.0.1.1-ISZdXKCdEZI2kyFA42ACof
    bytestring-0.10.8.1 text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-unicode-transforms/html/unicode-transforms.haddock
haddock-html: /usr/share/doc/haskell-unicode-transforms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-transforms-0.3.3-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unicode-transforms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unicode-transforms
version: 0.3.3
id: unicode-transforms-0.3.3-8gvD6OqHK6vA4hBSaCp1sL
key: unicode-transforms-0.3.3-8gvD6OqHK6vA4hBSaCp1sL
license: BSD3
copyright: 2016-2017 Harendra Kumar,
           2014–2015 Antonio Nikishaev
maintainer: harendra.kumar@gmail.com
stability: Experimental
homepage: http://github.com/harendra-kumar/unicode-transforms
synopsis: Unicode normalization
description:
    Fast Unicode 9.0 normalization in Haskell (NFC, NFKC, NFD, NFKD).
category: Data,Text,Unicode
author: Harendra Kumar
exposed: True
indefinite: False
exposed-modules:
    Data.ByteString.UTF8.Normalize Data.Text.Normalize
    Data.Unicode.Types
hidden-modules: Data.Unicode.Internal.NormalizeStream
                Data.Unicode.Properties.BitArray
                Data.Unicode.Properties.CombiningClass
                Data.Unicode.Properties.Compositions
                Data.Unicode.Properties.Decomposable
                Data.Unicode.Properties.DecomposableK
                Data.Unicode.Properties.Decompose
                Data.Unicode.Properties.DecomposeHangul
                Data.Unicode.Properties.Decompositions
                Data.Unicode.Properties.DecompositionsK
                Data.Unicode.Properties.DecompositionsK2
abi: ab44777527d79af4ce9646360914e5ba
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/unicode-transforms-0.3.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/unicode-transforms-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/unicode-transforms-0.3.3
hs-libraries: HSunicode-transforms-0.3.3-8gvD6OqHK6vA4hBSaCp1sL
depends:
    base-4.10.0.0 bitarray-0.0.1.1-HeOxnSR31kG5HiXVftr4YL
    bytestring-0.10.8.2 text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bitarray-0.0.1.1-HeOxnSR31kG5HiXVftr4YL=4a6633b2c01d659312fc3bb7a2409c64
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
haddock-interfaces: /usr/share/doc/haskell-unicode-transforms/html/unicode-transforms.haddock
haddock-html: /usr/share/doc/haskell-unicode-transforms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
